body {
  margin: 0;
  padding: 0;
  width: 100%;
  height: 100%;
  background-color: #f8f9fa;
  position: absolute;
}

.light {
  background-color: "<%body_bg_color%>";
  color: "<%text_color%>";
}

.dark {
  background-color: "<%body_bg_color_dark%>";
  color: "<%text_color_dark%>";
}

.markdown-body {
  margin-top: 2%;
  margin-left: "<%markdown_body_left%>";
  margin-right: "<%markdown_body_right%>";
  padding: 20px 50px;
  -ms-text-size-adjust: 100%;
  -webkit-text-size-adjust: 100%;
  line-height: 1.5;
  /* color: #24292e; */
  font-family: "<%font_family%>";
  font-size: "<%font_size%>";
  letter-spacing: "<%letter_spacing%>";
  line-height: 1.5;
  word-wrap: break-word;
  border-radius: 10px;
  box-shadow: "<%markdown_box_shadow%>";
  /* background-color: rgb(255, 255, 255); */
}

.markdown-light {
  background-color: "<%markdown_bg_color%>";
}

.markdown-light h1,
.markdown-light h2,
.markdown-light h3,
.markdown-light h4,
.markdown-light h5,
.markdown-light h6 {
  color: "<%hash_header_color%>";
}

.markdown-light a {
  color: "<%post_link_color%>";
  transition: all 0.8s;
}

.markdown-light a:hover {
  color: "<%link_hover_color%>";
  transition: all 0.8s;
}

.markdown-dark {
  background-color: #252d38;
}

.markdown-dark a {
  color: "<%post_link_color_dark%>";
  transition: all 0.8s;
}

.markdown-dark a:hover {
  color: "<%link_hover_color_dark%>";
  transition: all 0.8s;
}

.markdown-dark h1,
.markdown-dark h2,
.markdown-dark h3,
.markdown-dark h4,
.markdown-dark h5,
.markdown-dark h6 {
  color: "<%hash_header_color_dark%>";
}

.markdown-body strong {
  font-weight: inherit;
  font-weight: bolder;
}

.markdown-body h1 {
  font-size: 2em;
  margin: 0.67em 0;
}

.markdown-body img {
  border-style: none;
}

a {
  color: rgb(4, 105, 221);
  text-decoration: none;
}

a:hover {
  text-decoration: underline;
}

blockquote {
  margin: 0;
  margin-top: 10px;
  margin-bottom: 16px;
  padding: 0 1em;
  color: #6a737d;
  border-left: 0.25em solid #dfe2e5;
}

.markdown-body code,
.markdown-body kbd,
.markdown-body pre {
  font-family: SFMono-Regular, Consolas, Liberation Mono, Menlo, monospace;
  font-size: 15px;
}

.markdown-body strong {
  font-weight: 600;
}

.markdown-body hr {
  height: 0;
  margin: 15px 0;
  overflow: hidden;
  background: transparent;
  border: 0;
  border-bottom: 1px solid #dfe2e5;
}

.markdown-body hr:after,
.markdown-body hr:before {
  display: table;
  content: "";
}

.markdown-body blockquote,
.markdown-body details,
.markdown-body dl,
.markdown-body ol,
.markdown-body p,
.markdown-body table,
.markdown-body ul {
  margin-top: 0;
  margin-bottom: 16px;
}

.markdown-body pre {
  margin-top: 5px;
  margin-bottom: 16px;
  padding: 16px;
  overflow: auto;
  font-size: 85%;
  line-height: 1.45;
  background-color: #f6f8fa;
  border-radius: 3px;
  word-wrap: normal;
  box-shadow: "<%markdown_code_box_shadow%>";
}

.markdown-body code {
  padding: 0.2em 0.4em;
  margin: 0;
  font-size: 85%;
  background-color: rgba(27, 31, 35, 0.05);
  border-radius: 3px;
}

.markdown-body pre > code {
  padding: 0;
  margin: 0;
  font-size: 100%;
  word-break: normal;
  white-space: pre;
  background: transparent;
  border: 0;
}

.markdown-body pre code {
  display: inline;
  max-width: auto;
  padding: 0;
  margin: 0;
  overflow: visible;
  line-height: inherit;
  word-wrap: normal;
  background-color: initial;
  border: 0;
}

.markdown-body ul {
  padding-left: 0;
  margin-top: 0;
  margin-bottom: 0;
}

.markdown-body ol ol,
.markdown-body ul ol {
  list-style-type: lower-roman;
}

.markdown-body ol ol ol,
.markdown-body ol ul ol,
.markdown-body ul ol ol,
.markdown-body ul ul ol {
  list-style-type: lower-alpha;
}

.markdown-body ul {
  margin-top: 0;
  margin-bottom: 16px;
}

.markdown-body ol,
.markdown-body ul {
  padding-left: 2em;
}

.markdown-body ol ol,
.markdown-body ol ul,
.markdown-body ul ol,
.markdown-body ul ul {
  margin-top: 0;
  margin-bottom: 0;
}

.markdown-body li {
  word-wrap: break-all;
}

.markdown-body li > p {
  margin-top: 16px;
}

.markdown-body li + li {
  margin-top: 0.25em;
}

.markdown-body table {
  border-spacing: 0;
  border-collapse: collapse;
}

.markdown-body table th {
  font-weight: 600;
  white-space: nowrap;
}

.markdown-body table td,
.markdown-body table th {
  padding: 6px 13px;
  border: 1px solid #dfe2e5;
}

.markdown-body table tr {
  background-color: #fff;
  border-top: 1px solid #c6cbd1;
}

.markdown-body table tr:nth-child(2n) {
  background-color: #f6f8fa;
}

.markdown-body table {
  border-spacing: 0;
  border-collapse: collapse;
}

.markdown-body h1,
.markdown-body h2,
.markdown-body h3,
.markdown-body h4,
.markdown-body h5,
.markdown-body h6 {
  margin-top: 24px;
  margin-bottom: 16px;
  font-weight: 600;
  line-height: 1.25;
}

.markdown-body p img {
  max-width: 80%;
  display: block;
  margin: 0 auto;
  box-shadow: "<%markdown_picture_box_shadow%>";
  border-radius: 5px;
}

.markdown-body pre {
  position: relative;
}

.changeMode {
  position: absolute;
  right: 50px;
  top: 50px;
  padding: 5px;
  border-radius: 50%;
  background-color: #e3e3e3;
  box-shadow: rgba(0, 0, 0, 0.25) 0px 54px 55px,
    rgba(0, 0, 0, 0.12) 0px -12px 30px, rgba(0, 0, 0, 0.12) 0px 4px 6px,
    rgba(0, 0, 0, 0.17) 0px 12px 13px, rgba(0, 0, 0, 0.09) 0px -3px 5px;
}

.markdown-body pre #code_copy {
  position: absolute;
  right: 10px;
  top: 50%;
  margin-top: -16px;
  padding: 3px;
  opacity: 0.9;
  border: 1px solid rgba(149, 157, 165, 0.2);
  transition: all 0.5s;
  border-radius: 5px;
}

.markdown-light pre #code_copy {
  background-color: rgb(196, 196, 196);
}

.markdown-body pre #code_copy:hover {
  transition: all 0.5s;
  background-color: #ffffff;
  box-shadow: rgba(149, 157, 165, 0.2) 0px 8px 24px;
  border-radius: 5px;
}

.markdown-body pre #code_copy:active {
  padding: 2px;
}

.markdown-light :not(pre) > code[class*="language-"],
.markdown-light pre[class*="language-"] {
  background: "<%markdown_code_bg_color%>";
}

.markdown-dark :not(pre) > code[class*="language-"],
.markdown-dark pre[class*="language-"] {
  background: "<%markdown_code_bg_color_dark%>";
}

.markdown-light .token.cdata,
.markdown-light .token.comment,
.markdown-light .token.doctype,
.markdown-light .token.prolog {
  color: "<%markdown_code_comment%>";
}

.markdown-dark .token.cdata,
.markdown-dark .token.comment,
.markdown-dark .token.doctype,
.markdown-dark .token.prolog {
  color: "<%markdown_code_comment_dark%>";
}

.markdown-light code[class*="language-"],
.markdown-light pre[class*="language-"] {
  color: "<%markdown_code_text%>";
}

.markdown-dark code[class*="language-"],
.markdown-dark pre[class*="language-"] {
  color: "<%markdown_code_text_dark%>";
}

code[class*="language-"] ::-moz-selection,
code[class*="language-"]::-moz-selection,
pre[class*="language-"] ::-moz-selection,
pre[class*="language-"]::-moz-selection {
  text-shadow: none;
  background: "<%markdown_code_selected%>";
  color: "<%markdown_code_color_selected%>";
}
code[class*="language-"] ::selection,
code[class*="language-"]::selection,
pre[class*="language-"] ::selection,
pre[class*="language-"]::selection {
  text-shadow: none;
  background: "<%markdown_code_selected%>";
  color: "<%markdown_code_color_selected%>";
}

.token.punctuation {
  color: "<%markdown_code_punctuation%>";
}

.markdown-light .token.boolean,
.markdown-light .token.constant,
.markdown-light .token.deleted,
.markdown-light .token.number,
.markdown-light .token.property,
.markdown-light .token.symbol,
.markdown-light .token.tag {
  color: "<%markdown_code_constant%>";
}

.markdown-dark .token.boolean,
.markdown-dark .token.constant,
.markdown-dark .token.deleted,
.markdown-dark .token.number,
.markdown-dark .token.property,
.markdown-dark .token.symbol,
.markdown-dark .token.tag {
  color: "<%markdown_code_constant_dark%>";
}

.markdown-light .token.attr-name,
.markdown-light .token.builtin,
.markdown-light .token.char,
.markdown-light .token.inserted,
.markdown-light .token.selector,
.markdown-light .token.string {
  color: "<%markdown_code_string%>";
}

.markdown-dark .token.attr-name,
.markdown-dark .token.builtin,
.markdown-dark .token.char,
.markdown-dark .token.inserted,
.markdown-dark .token.selector,
.markdown-dark .token.string {
  color: "<%markdown_code_string_dark%>";
}

.markdown-light .language-css .token.string,
.markdown-light .style .token.string,
.markdown-light .token.entity,
.markdown-light .token.operator,
.markdown-light .token.url {
  color: "<%markdown_code_operator%>";
  /* background: hsla(0, 0%, 100%, 0.5); */
}

.markdown-dark .language-css .token.string,
.markdown-dark .style .token.string,
.markdown-dark .token.entity,
.markdown-dark .token.operator,
.markdown-dark .token.url {
  color: "<%markdown_code_operator_dark%>";
  /* background: hsla(0, 0%, 100%, 0.5); */
}

.markdown-light .token.atrule,
.markdown-light .token.attr-value,
.markdown-light .token.keyword {
  color: "<%markdown_code_keyword%>";
}

.markdown-dark .token.atrule,
.markdown-dark .token.attr-value,
.markdown-dark .token.keyword {
  color: "<%markdown_code_keyword_dark%>";
}

.markdown-light .token.function {
  color: "<%markdown_code_function%>";
}

.markdown-dark .token.function {
  color: "<%markdown_code_function_dark%>";
}

.markdown-light .token.class-name {
  color: "<%markdown_code_class%>";
}

.markdown-dark .token.class-name {
  color: "<%markdown_code_class_dark%>";
}

.change-article {
  font-family: "<%font_family%>";
  border: 0;
  width: 100%;
  margin-right: 20%;
  height: 100px;
  margin-top: 50px;
  border-radius: 10px;
  transition: all 0.5s;
  box-shadow: rgba(149, 157, 165, 0.2) 0px 8px 24px;
}

.change-article:hover {
  cursor: pointer;
  font-weight: bolder;
  transition: all 0.5s;
  box-shadow: rgba(100, 100, 111, 0.4) 0px 7px 29px 0px;
}

.change-article:active {
  width: 95%;
  height: 90px;
}

.next-front {
  position: fixed;
  right: 10%;
  top: 40%;
  width: 10%;
  /* white-space:nowrap; */
}

.dir-tree::-webkit-scrollbar{
  display:none /* Chrome Safari */
}

.dir-tree {
  font-family: "<%font_family%>";
  position: fixed;
  left: "<%dir_left%>";
  top: "<%dir_top%>";
  width: "<%dir_width%>";
  min-width: 100px;
  box-shadow: rgba(149, 157, 165, 0.2) 0px 8px 24px;
  background-color: #f6f8fa;
  border-radius: 10px;
  max-height: 80%;
  overflow: auto;
  scrollbar-width: none; /* Firefox */
  -ms-overflow-style: none; /* IE 10+ */
  text-overflow:ellipsis; /*  过长文字省略号 */
  white-space:nowrap /*禁止文字折行*/
}

.dir-tree ul {
  font-family: "<%font_family%>";
  font-size: "<%dir_item_font_size%>";
  letter-spacing: "<%letter_spacing%>";
  margin-top: "<%dir_item_margin%>";
  margin-bottom: "<%dir_item_margin%>";
  margin-left: "<%dir_item_margin_left%>";
  list-style: none;
  position: relative;
  /* box-shadow: rgba(149, 157, 165, 0.2) 0px 8px 24px; */
}



/* .dir-tree ul ul li::after {
  content: "";
  width: 0;
  height: 3px;
  position: absolute;
  background: #000;
  top: 100%;
  right: 50%;
  transition: all .5s;
}

.dir-tree ul ul li:hover::after{
  width: 30%;
  right: 0;
} */

.dir-tree ul ul li {
  font-family: "<%font_family%>";
  letter-spacing: "<%letter_spacing%>";
  font-size: "<%dir_second_item_font_size%>";
  margin-left: -10px;
  margin-top: -10px;
  /* margin-bottom: 10px; */
  padding-left: "<%dir_second_item_margin_left%>";
  padding-top: 10px;
  padding-bottom: "<%dir_second_item_margin%>";
  border-radius: 10px;
  /* padding-right: -10px; */
}

/* .dir-tree ul ul li:hover {
  background-color: "<%body_bg_color%>";
} */

.dir-tree a {
  
  text-decoration: none;
  color: "<%dir_tree_color%>";
}

.dir-tree a:hover {
  font-weight: bold;
  color: "<%dir_tree_hover_color%>";
  /* text-decoration: underline; */
}

.dir-tree ul ul li a {
  color: "<%dir_second_tree_color%>";
}

.dir-tree ul ul li a:hover {
  color: "<%dir_second_tree_hover_color%>";
}

/* 图片下的文字的样式 */

.markdown-body p > p {
  color: "<%picture_text_color%>";
  margin-top: 10px;
  text-align: center;
  line-height: 100%;
}

.preview-image {
  position: fixed;
  top: 50%;
  left: 50%;
  transform: translate(-50%, -50%);
  width: "<%image_preview_width%>";
  z-index: 200;
}

#black_overlay {
  display: none;
  position: fixed;
  top: 0;
  left: 0;
  width: 100%;
  height: 100%;
  background-color: "<%picture_preview_bg_color%>";
  z-index: 100;
}

.zood {
  text-decoration: none;
  color: grey;
  text-align: center;
  display: block;
}

.markdown-body input {
  margin-top: 10px;
  margin-bottom: 10px;
}